"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNodeVersion = getNodeVersion;
exports.downloadNodeVersion = downloadNodeVersion;
const node_resolver_1 = require("@pnpm/node.resolver");
const getNodeMirror_1 = require("./getNodeMirror");
const node_1 = require("./node");
const parseEnvSpecifier_1 = require("./parseEnvSpecifier");
const fetch_1 = require("@pnpm/fetch");
const logger_1 = require("@pnpm/logger");
async function getNodeVersion(opts, envSpecifier) {
    const fetch = (0, fetch_1.createFetchFromRegistry)(opts);
    const { releaseChannel, versionSpecifier } = (0, parseEnvSpecifier_1.parseEnvSpecifier)(envSpecifier);
    const nodeMirrorBaseUrl = (0, getNodeMirror_1.getNodeMirror)(opts.rawConfig, releaseChannel);
    const nodeVersion = await (0, node_resolver_1.resolveNodeVersion)(fetch, versionSpecifier, nodeMirrorBaseUrl);
    return { nodeVersion, nodeMirrorBaseUrl, releaseChannel, versionSpecifier };
}
async function downloadNodeVersion(opts, envSpecifier) {
    const fetch = (0, fetch_1.createFetchFromRegistry)(opts);
    const { nodeVersion, nodeMirrorBaseUrl } = await getNodeVersion(opts, envSpecifier);
    if (!nodeVersion) {
        return null;
    }
    const nodeDir = await (0, node_1.getNodeDir)(fetch, {
        ...opts,
        useNodeVersion: nodeVersion,
        nodeMirrorBaseUrl,
    });
    (0, logger_1.globalInfo)(`Node.js ${nodeVersion} was installed
  ${nodeDir}`);
    return { nodeVersion, nodeDir, nodeMirrorBaseUrl };
}
//# sourceMappingURL=downloadNodeVersion.js.map